@@ -16,7 +16,7 @@ SHORT_HELP = "Config the AK/SK and region for CFC"
 @click.option('-l', '--location', help="Configfile location, ~/.bce as default")
 @click.option('--ak', prompt='BCE Access Key ID', help='Known as AK')
 @click.option('--sk', prompt='BCE Secret Access Key', help='Known as SK')
-@click.option('--region', prompt='BCE region', help='Known as REGION')
+@click.option('--region', type=click.Choice(['bj','gz','su']), prompt='BCE region', help='Known as REGION')
 @common_options
 @pass_context
 def cli(ctx, location, ak, sk, region):
