@@ -26,7 +26,8 @@ $ bsam local generate-event bos put --bucket <bucket> --object <object> | bsam l
 """
 
 
-@click.command(name="generate-event", cls=GenerateEventCommand, help=HELP_TEXT)
+@click.command(name="generate-event", cls=GenerateEventCommand, help=HELP_TEXT, 
+    context_settings=dict(help_option_names=[u'-h', u'--help']))
 @pass_context
 def cli(self):
     """
