@@ -8,8 +8,8 @@ import click
 from .invoke.cli import cli as invoke_cli
 from .generate_event.cli import cli as generate_event_cli
 from .install.cli import cli as install_cli
+from .start_api.cli import cli as start_api_cli
 # from .start_lambda.cli import cli as start_lambda_cli
-# from .start_api.cli import cli as start_api_cli
 
 
 @click.group()
@@ -24,5 +24,5 @@ def cli():
 cli.add_command(invoke_cli)
 cli.add_command(generate_event_cli)
 cli.add_command(install_cli)
-# cli.add_command(start_api_cli)
+cli.add_command(start_api_cli)
 # cli.add_command(start_lambda_cli)
